---
name: Security Issue
about: Fix Security Issue
title: <Insert Title>
labels: security
assignees: ''

---

# Summary
<!---
A short summary of the security issue.
--->

|            |     |
|------------|-----|
| Class/Type | -   |
| Version(s) | -   |
| Severity   | -   |
| CVE Number | -   |

<!---
A quick table based overview, containing the most important details.

Class/Type: Of vulnerability, e.g. xss, buffer-overflow, ... (see https://cwe.mitre.org/
Versions: Affected software versions
Severity: Of the vulnerability (Low, Medium, High, Critical)
CVE Number: number and link to the cve if available
-->


# Details

### Description
<!---
If no detailed information is available through references or CVE, an extensive
description of the vulnerability should be added here.
--->

### Impact
<!---
Describe the impact of the vulnerability.
--->

### References
<!---
Links to related issues or other sources like link to CVE.
--->

# Solutions
<!--
Describe possible solution(s), how to address this issue.
--->

# Credit
<!--
Whom to thank, kudos for the reporter(s)
-->
